import { _fetch as fetch } from './_fetch.js';
import { FetchUrlError, toFetchUrlError } from './FetchError.js';
// eslint-disable-next-line n/no-unsupported-features/node-builtins
export async function fetchHead(request) {
    const url = toURL(request);
    try {
        const r = await fetch(url, { method: 'HEAD' });
        if (!r.ok) {
            throw FetchUrlError.create(url, r.status);
        }
        return r.headers;
    }
    catch (e) {
        throw toFetchUrlError(e, url);
    }
}
export async function fetchURL(url) {
    try {
        const response = await fetch(url);
        if (!response.ok) {
            throw FetchUrlError.create(url, response.status);
        }
        return Buffer.from(await response.arrayBuffer());
    }
    catch (e) {
        throw toFetchUrlError(e, url);
    }
}
function toURL(url) {
    return typeof url === 'string' ? new URL(url) : url;
}
//# sourceMappingURL=fetch.js.map