import type { FindResult, ITrieNode, ITrieNodeId, ITrieNodeRoot } from '../ITrieNode/ITrieNode.js';
import type { FastTrieBlobInternalsAndMethods } from './FastTrieBlobInternals.js';
type Node = Readonly<Uint32Array>;
type NodeIndex = number;
declare class FastTrieBlobINode implements ITrieNode {
    readonly trie: FastTrieBlobInternalsAndMethods;
    readonly nodeIdx: NodeIndex;
    readonly id: number;
    readonly node: Node;
    readonly eow: boolean;
    private _keys;
    private _count;
    private _size;
    private _chained;
    private _nodesEntries;
    private _entries;
    private _values;
    protected charToIdx: Readonly<Record<string, NodeIndex>> | undefined;
    constructor(trie: FastTrieBlobInternalsAndMethods, nodeIdx: NodeIndex);
    /** get keys to children */
    keys(): readonly string[];
    values(): readonly ITrieNode[];
    entries(): readonly (readonly [string, ITrieNode])[];
    /** get child ITrieNode */
    get(char: string): ITrieNode | undefined;
    getNode(chars: string): ITrieNode | undefined;
    has(char: string): boolean;
    hasChildren(): boolean;
    child(keyIdx: number): ITrieNode;
    getCharToIdxMap(): Record<string, number>;
    findExact(word: string): boolean;
    isForbidden(word: string): boolean;
    findCaseInsensitive(word: string): boolean;
    private containsChainedIndexes;
    private getNodesEntries;
    private walkChainedIndexes;
    get size(): number;
}
export declare class FastTrieBlobIRoot extends FastTrieBlobINode implements ITrieNodeRoot {
    readonly hasForbiddenWords: boolean;
    readonly hasCompoundWords: boolean;
    readonly hasNonStrictWords: boolean;
    constructor(trie: FastTrieBlobInternalsAndMethods, nodeIdx: number);
    resolveId(id: ITrieNodeId): ITrieNode;
    find(word: string, strict: boolean): FindResult | undefined;
    get info(): Readonly<import("../trie.js").TrieOptions>;
    get forbidPrefix(): string;
    get compoundFix(): string;
    get caseInsensitivePrefix(): string;
}
export {};
//# sourceMappingURL=FastTrieBlobIRoot.d.ts.map